@@ -374,7 +374,8 @@ class DiscoveryService(AbstractDiscoveryService, DatagramProtocol, Listener):
     def _discovery_recieved(self, data):
         message = data.decode().split(',')
         if (len(message) < 3 or message[0] != 'ASPort_12107'
-            or (len(message) >= 4 and not message[3] in ('iZone', 'iZoneV2'))):
+                or (len(message) >= 4
+                    and not message[3] in ('iZone', 'iZoneV2'))):
             _LOG.warning("Invalid Message Received: %s", data.decode())
             return
 
